This function makes prediction based on conditional simulation in autogressive cokriging models for multivariate output
mvcokm.condsim(obj, input.new, nsample = 30)a mvcokm object construted via the function mvcokm in
this package
a matrix including new inputs for making prediction
a numerical value indicating the number of samples
Pulong Ma <mpulong@gmail.com>
mvcokm, mvcokm.fit, mvcokm.predict, ARCokrig